/**
 * Copyright 2022 CS GROUP - France, http://www.c-s.fr
 * All rights reserved
 */

/**
 * Address used to contact the EODAG server
 * This is the notebook server REST API extension
 */
export const EODAG_SERVER_ADDRESS = 'eodag';

/**
 * Address used to contact the EODAG settings
 */
export const EODAG_SETTINGS_ADDRESS = 'api/settings/eodag-labextension:plugin';
