/**
 * Copyright 2022 CS GROUP - France, http://www.c-s.fr
 * All rights reserved
 */

declare module '@terraformer/wkt';

// Module '@terraformer/wkt' resolves to an untyped module at '/node_modules/@terraformer/wkt/dist/t-wkt.umd.js', which cannot be augmented.

// If it could be augmented, it would contain this:

// import * as GeoJSON from "geojson";

// export function wktToGeoJSON(element: string): GeoJSON.GeometryObject;
// export function geojsonToWKT (geojson: GeoJSON.GeometryObject): string;
