"use strict";(self.webpackChunkeodag_labextension=self.webpackChunkeodag_labextension||[]).push([[6005],{6005:(e,t,n)=>{n.r(t),n.d(t,{NonceProvider:()=>p,components:()=>h.c,createFilter:()=>o.c,default:()=>v,defaultTheme:()=>o.d,mergeStyles:()=>o.m,useStateManager:()=>r.u});var r=n(9234),a=n(5285),c=n(3345),o=n(3939),i=n(9542),u=n(6752),s=n(62),h=n(2737),l=n(9553),f=n(4162),d=n(1811),m=(n(7628),(0,c.forwardRef)((function(e,t){var n=(0,r.u)(e);return c.createElement(o.S,(0,a.A)({ref:t},n))}))),p=function(e){(0,s.A)(n,e);var t=(0,h._)(n);function n(e){var r;return(0,i.A)(this,n),(r=t.call(this,e)).createEmotionCache=function(e,t){return(0,f.A)({nonce:e,key:t})},r.createEmotionCache=(0,d.A)(r.createEmotionCache),r}return(0,u.A)(n,[{key:"render",value:function(){var e=this.createEmotionCache(this.props.nonce,this.props.cacheKey);return c.createElement(l.CacheProvider,{value:e},this.props.children)}}]),n}(c.Component);const v=m}}]);