:root {
  --light-gray: #c1c1c1;
  --gray: #666666;
  --base-button: #1976d2;
  --button-hover: #3bacff;
  --border-radius: 5px;
  --base-font-size: 14px;
}

.MuiTooltip-popper {
  z-index: 10001 !important; /* To go over jp Dialog */
}

p {
  margin: unset;
}

.sizeFull {
  width: 100%;
  height: 100%;
}

.jp-EodagWidget {
  display: flex;
  flex-direction: column;
  height: 100%;
  color: var(--jp-ui-font-color1);
  background: var(--jp-layout-color1);
  font-size: var(--jp-ui-font-size1);
  overflow: auto;
  padding: 5px;
}

.jp-EodagWidget-products-search {
  overflow: auto;
  height: 100%;
}

.jp-EodagWidget-header-wrapper {
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.jp-EodagWidget-header {
  border-bottom: var(--jp-border-width) solid var(--jp-border-color2);
  flex: 0 0 auto;
  font-size: var(--jp-ui-font-size0);
  font-weight: 600;
  letter-spacing: 1px;
  margin: 0px;
  padding: 8px 12px;
  text-transform: uppercase;
}

.jp-EodagWidget-settings-wrapper {
  display: flex;
  flex-direction: row;
}

.jp-EodagWidget-settings-wrapper button {
  padding: 1px 4px;
}

.jp-EodagWidget-settings-wrapper button:focus-visible {
  outline: none;
}

.jp-EodagWidget-wrapper {
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  height: calc(100% - 2rem);
}

.jp-EodagWidget .jp-EodagWidget-form {
  display: flex;
  flex-direction: column;
  gap: 1.5rem;
  flex: 1;
}

.jp-EodagWidget-form-buttons {
  width: 100%;
  max-width: 450px;
}

.jp-EodagWidget-loader {
  margin-top: 10px;
  width: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
}

.jp-EodagWidget-loader svg {
  width: 2rem;
  height: 2rem;
  fill: #1976d2;
}

.jp-EodagWidget-loader p {
  margin-right: 10px;
  font-weight: bold;
}

.jp-EodagWidget-input-error {
  border: 2px solid red !important;
  border-radius: 5px;
}

.jp-EodagWidget .jp-EodagWidget-form .react-datepicker-popper {
  position: relative;
  z-index: 1000;
}

.jp-EodagWidget .jp-EodagWidget-form .jp-EodagWidget-slider {
  display: flex;
  align-items: center;
  height: 30px;
  overflow: hidden;
}

.jp-EodagWidget-map {
  height: 300px;
}

.jp-EodagWidget .jp-EodagWidget-form .jp-EodagWidget-field fieldset {
  margin-top: 1.5em;
}

.jp-EodagWidget-input-name-checkbox-wrapper {
  margin-top: 1em;
  display: flex;
  flex-direction: row-reverse;
  justify-content: start;
  align-items: center;
}

.jp-EodagWidget .jp-EodagWidget-form .jp-EodagWidget-input-wrapper {
  padding: 0px 8px;
  border: 1px solid var(--jp-border-color0);
  background: var(--jp-layout-color0);
  height: 30px;
  position: relative;
  border-radius: 5px;
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-input-wrapper:nth-child(1) {
  margin-right: 0.1rem;
}

.jp-EodagWidget .jp-EodagWidget-form .jp-EodagWidget-input-wrapper:after {
  content: ' ';
  position: absolute;
  right: 5px;
  top: 5px;
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-input-wrapper:focus-within {
  border: 1px solid #2196f3;
}

.jp-EodagWidget .jp-EodagWidget-form .jp-EodagWidget-input {
  background: transparent;
  border: none;
  outline: none;
  font-size: var(--jp-ui-font-size1);
  color: var(--jp-ui-font-color0);
  line-height: var(--jp-private-commandpalette-search-height);
  width: 100%;
}

.jp-EodagWidget .jp-EodagWidget-form .jp-EodagWidget-input::placeholder {
  color: var(--gray);
}

.jp-EodagWidget .jp-EodagWidget-form .jp-EodagWidget-section-title {
  font-weight: bold;
  text-transform: uppercase;
}

.jp-EodagWidget .jp-EodagWidget-form .jp-EodagWidget-optional-button {
  display: flex;
  align-items: center;
  border: none;
  background: none;
  color: #2196f3;
  font-size: 14px;
  cursor: pointer;
  padding: 5px;
}

.jp-EodagWidget .jp-EodagWidget-form .jp-EodagWidget-optional-button:disabled {
  color: gray;
  cursor: not-allowed;
}

.jp-EodagWidget-optional-params-wrapper {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.jp-EodagWidget-optional-params-title {
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-optional-button:not(:disabled):hover {
  color: rgb(59, 172, 255);
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-fields
  .jp-EodagWidget-additionalParameters {
  display: flex;
  flex-direction: column;
  gap: 0.5rem;
}

.jp-EodagWidget-additionalParameters-title {
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-fields
  .jp-EodagWidget-additionalParameters
  .section {
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-fields
  .jp-EodagWidget-additionalParameters
  .section
  input {
  height: 2rem;
  padding: 0 0.5rem;
  border-radius: 5px;
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-fields
  .jp-EodagWidget-additionalParameters
  input {
  margin: 0 0.1em;
  line-height: var(--jp-private-commandpalette-search-height);
  border: 1px solid var(--jp-border-color0);
  background: var(--jp-layout-color0);
  color: var(--jp-ui-font-color0);
  width: 40%;
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-fields
  .jp-EodagWidget-additionalParameters
  .jp-EodagWidget-additionalParameters-label-icon-wrapper {
  display: flex;
  align-items: center;
  margin-bottom: 10px;
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-fields
  .jp-EodagWidget-additionalParameters
  .jp-EodagWidget-additionalParameters-label-icon-wrapper
  a {
  display: inline-flex;
  margin-left: 5px;
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-fields
  .jp-EodagWidget-additionalParameters
  .jp-EodagWidget-additionalParameters-label-icon-wrapper
  a:hover {
  color: #677381;
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-fields
  .jp-EodagWidget-additionalParameters
  input:focus-within {
  border: 1px solid #2196f3;
}

.jp-EodagWidget
  .jp-EodagWidget-form
  .jp-EodagWidget-fields
  .jp-EodagWidget-additionalParameters
  input::placeholder {
  padding-left: 0.3rem;
}

section button .jp-EodagWidget-additionalParameters-deletebutton svg,
section button .jp-EodagWidget-additionalParameters-addbutton svg {
  color: #000000;
  background-color: #ffffff;
}

.jp-EodagWidget-additionalParameters-deletebutton svg:hover,
.jp-EodagWidget-additionalParameters-addbutton svg:hover {
  color: #677381;
}

.jp-EodagWidget-select__input,
.jp-EodagWidget-select__control,
.jp-EodagWidget-select__value-container,
.jp-EodagWidget-select__indicator,
.jp-EodagWidget-select__menu,
.jp-EodagWidget-select__menu-list,
.jp-EodagWidget-select__optiooption {
  background-color: var(--jp-layout-color0);
  font-size: var(--jp-ui-font-size1);
  color: var(--jp-ui-font-color0);
  line-height: var(--jp-private-commandpalette-search-height);
  border-radius: 5px !important;
}

.jp-EodagWidget .jp-EodagWidget-form .react-datepicker-wrapper,
.jp-EodagWidget .jp-EodagWidget-form .react-datepicker__input-container {
  width: 100%;
}

.jp-EodagWidget-select__indicator-separator,
.jp-EodagWidget-select__dropdown-indicator > div > svg {
  color: var(--light-gray) !important;
}

.jp-SettingsPanel legend {
  font-size: var(--jp-content-font-size2);
  color: var(--jp-ui-font-color0);
  flex-basis: 100%;
  padding: 4px 0;
  font-weight: var(--jp-content-header-font-weight);
  border-bottom: 1px solid var(--jp-border-color2);
}

.jp-EodagWidget-select__placeholder {
  color: var(--gray) !important;
}

.jp-EodagWidget input[type='range'] {
  width: 100%;
  appearance: none;
  -webkit-appearance: none;
  outline: none;
  background: var(--jp-layout-color0);
}

.jp-EodagWidget input[type='range']::-webkit-slider-runnable-track {
  width: 100%;
  height: 7px;
  cursor: pointer;
  background: var(--jp-layout-color0);
  border-radius: 0px;
  border: 1px solid var(--jp-border-color0);
}

.jp-EodagWidget input[type='range']::-webkit-slider-thumb {
  -webkit-appearance: none;
  appearance: none;
  padding: 0;
  height: 20px;
  width: 20px;
  border-radius: 50%;
  background-color: var(--jp-brand-color1);
  cursor: pointer;
  outline: none;
  color: var(--jp-brand-color1);
  margin-top: -8px;
}

.jp-EodagWidget input[type='range']::-moz-range-track {
  width: 100%;
  height: 7px;
  cursor: pointer;
  background: var(--jp-layout-color0);
  border-radius: 0px;
  border: 1px solid var(--jp-border-color0);
}

.jp-EodagWidget input[type='range']::-moz-range-thumb {
  appearance: none;
  padding: 0;
  height: 20px;
  width: 20px;
  border-radius: 50%;
  background-color: var(--jp-brand-color1);
  cursor: pointer;
  outline: none;
  color: var(--jp-brand-color1);
  margin-top: -8px;
}

.jp-EodagWidget input[type='range']::-moz-range-progress {
  height: 0;
  background: transparent;
}

.jp-EodagWidget input[type='range']::-ms-track {
  width: 100%;
  height: 7px;
  cursor: pointer;
  background: var(--jp-layout-color0);
  border-radius: 0px;
  border: 1px solid var(--jp-border-color0);
  color: transparent;
}

.jp-EodagWidget input[type='range']::-ms-thumb {
  appearance: none;
  padding: 0;
  height: 20px;
  width: 20px;
  border-radius: 50%;
  background-color: var(--jp-brand-color1);
  cursor: pointer;
  outline: none;
  color: var(--jp-brand-color1);
  margin-top: -8px;
}

.jp-EodagWidget input[type='range']::-ms-tooltip {
  display: none;
}

.jp-EodagWidget input[type='range']::-ms-fill-lower {
  background: transparent;
}

.jp-EodagWidget input[type='range']::-ms-fill-upper {
  background: transparent;
}

.jp-EodagWidget-appbar {
  flex: 1 100%;
  display: flex;
  justify-content: space-between;
  background-color: var(--jp-brand-color1);
  padding: 12px 10px;
  font-size: 20px;
  color: white;
}

.jp-Eodag-tooltip {
  max-width: 200px;
  padding: 8px 16px !important;
  text-align: center;
  word-wrap: break-word;
  z-index: 4;
}

#jp-left-stack {
  z-index: 2;
}

#jp-left-stack > .lm-Widget {
  min-width: 315px !important;
}

.jp-EodagWidget::-webkit-scrollbar {
  z-index: 0;
}

/* Design Table */

.jp-EodagWidget-browse-wrapper .noClick {
  cursor: initial;
}

.jp-EodagWidget-browse-wrapper .tableCell {
  flex: 1;
}

.jp-EodagWidget-browse-wrapper .headerRow {
  height: 40px;
  border-bottom: 2px solid #2196f3;
  color: #818181;
}

.jp-EodagWidget-browse-wrapper .tableRow {
  cursor: pointer;
  border-bottom: 1px solid rgba(180, 180, 180, 0.719);
}

.jp-EodagWidget-browse-wrapper .tableRow:hover {
  background-color: rgba(180, 180, 180, 0.747);
}

.jp-EodagWidget-browse-wrapper .flexContainer {
  text-align: center;
  font-size: 14px;
  display: flex;
  align-items: center;
  box-sizing: border-box;
  justify-content: center;
}

.jp-EodagWidget-appbar button,
.jp-EodagWidget-browse-wrapper button,
.jp-EodagWidget-modal-footer button {
  background: none;
  border: none;
  outline: none;
  font-size: 18px;
  cursor: pointer;
}

.jp-EodagWidget-appbar button,
.jp-EodagWidget-modal-footer button {
  color: white;
  border: 1px solid var(--button-hover);
  border-radius: 5px;
}

.jp-EodagWidget-modal-footer button {
  padding: 5px 10px;
}

.jp-EodagWidget-appbar button:hover,
.jp-EodagWidget-modal-footer button:hover {
  background-color: var(--button-hover);
}

.jp-EodagWidget-apply {
  float: right;
  padding: 3px 6px;
}

.jp-EodagWidget-product h4 {
  padding-left: 20px;
}

@keyframes spin {
  0% {
    transform: rotate(0deg);
  }

  100% {
    transform: rotate(360deg);
  }
}

.spin-icon {
  animation: spin 0.5s linear infinite;
}
